#
# spec file for package xtables-addons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xtables-addons
Version:        3.26
Release:        1.11.2.6.sr20240702
Summary:        IP Packet Filter Administration Extensions
License:        GPL-2.0-only AND GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://xtables-addons.sf.net/

#Git-Clone:	git://git.inai.de/xtables-addons
Source:         https://inai.de/files/%name/%name-%version.tar.xz
Source2:        https://inai.de/files/%name/%name-%version.tar.asc
Source3:        %name-preamble
Source4:        %name.keyring
Patch1:         sle-kernels.patch
BuildRequires:  modutils kernel-syms kmod-compat suse-kernel-rpm-scriptlets bash-sh kernel-syms-longterm
BuildRequires:  automake
BuildRequires:  kernel-syms >= 5.4 kernel-syms-longterm
BuildRequires:  libtool
BuildRequires:  pkg-config >= 0.21
BuildRequires:  xz
BuildRequires:  pkgconfig(xtables) >= 1.6.0
Requires:       perl(Getopt::Long)
Requires:       perl(Net::CIDR::Lite)
Requires:       perl(Socket)
Requires:       perl(Text::CSV_XS)
Requires:       perl(strict)
Requires:       perl(warnings)
Recommends:     %name-kmp
Recommends:     xtables-geoip

%define xtlibdir %(pkg-config xtables --variable=xtlibdir)

%kernel_module_package -p %name-preamble

%description
Xtables is used to set up, maintain, and inspect the tables of IP
packet filter rules in the Linux kernel.

Xtables-addons is the successor to patch-o-matic(-ng). Likewise, it
contains extensions that were not, or are not yet, accepted in the
main kernel/iptables packages.

%package KMP
Summary:        IP Packet Filter Administration Extensions
Group:          System/Kernel

%description KMP
Xtables is used to set up, maintain, and inspect the tables of IP
packet filter rules in the Linux kernel.

Xtables-addons is the successor to patch-o-matic(-ng). Likewise, it
contains extensions that were not, or are not yet, accepted in the
main kernel/iptables packages.

%prep
%autosetup -p1
autoreconf -fiv

%build
%if 0%{?sle_version} == 150300
export KCFLAGS="-DSLE_15_3"
echo "$KCFLAGS" >kcflags
%endif
pushd ../
for flavor in %flavors_to_build; do
	cp -a "%name-%version" "%name-$flavor-%version"
	pushd "%name-$flavor-%version/"
	%configure --with-kbuild="/usr/src/linux-obj/%_target_cpu/$flavor"
	%make_build %{?linux_make_arch} V=1
	popd
done

%install
b="%buildroot"
# kernel's make install is picky about flags changing between %%build and %%install
export KCFLAGS="$(cat kcflags)"
pushd ../
for flavor in %flavors_to_build; do
	pushd "%name-$flavor-%version/"
	%make_install %{?linux_make_arch} V=1
	popd
done
# There is no -devel package. So no need for these files.
find "$b/%_prefix" -iname "*.la" -delete
find "$b/%_libdir" -maxdepth 1 -type l -iname "*.so" -delete

%ldconfig_scriptlets

%files
%_bindir/xt_geoip*
%_mandir/man*/*
%_sbindir/*
%_libdir/*.so.*
%xtlibdir/
%_libexecdir/xtables-addons/
%license LICENSE

%changelog
* Fri Mar 22 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.26
  * xt_pknock: fix misuse of shash API
  * xt_SYSRQ: resolve crash, switch to new SHASH_ON_STACK
* Sun Dec 17 2023 Jan Engelhardt <jengelh@inai.de>
- Trim default KMP preamble content
* Fri Aug 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.25
  * xt_ipp2p: change text-search algo to KMP
    (fix some false negative matches)
* Mon May 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.24
  * xt_geoip: bump number of territories per rule
  * geoip: use stdout for output and stderr for errors/diag
* Thu Jan 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.23
  * Support for Linux 6.2
* Tue Oct 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.22
  * Support for up to Linux 6.1
* Mon Jun 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.21
  * Linux 5.10.x stable branch: support for Linux 5.10.121
* Sun Apr 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.20
  * Linux 5.17 support
* Tue Feb  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.19
  * xt_ipp2p: add IPv6 support
* Fri Mar 19 2021 Jan Engelhardt <jengelh@inai.de>
- Add sle-kernels.patch [boo#1183753]
* Thu Mar 11 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.18
  * Fix ARM 32-bit build failure
* Sun Feb 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.17
  * xt_pknock: cure a NULL dereference
* Wed Feb 24 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.16
  * i586 platform build fix
* Fri Feb  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.15
  * xt_lscan: add --mirai option
  * Support for Linux 5.11
  * xt_geoip_fetch was renamed to xt_geoip_query to better
    reflect its purpose
* Thu Nov 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.12
  * Support for Linux 5.10 and the API/ABI change in 5.9.9
* Wed Sep 16 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.11
  * Support for Linux 5.9
* Tue Feb 25 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9
  * Support for Linux 5.6 [boo#1164758]
* Mon Feb  3 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8
  * Support for Linux 5.5
  * The xt_geoip_build script now takes DBIP as input
* Sun Dec  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.7
  * xt_geoip: fix in6_addr little-endian byte swapping
* Wed Nov 20 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.6
  * Support for Linux 5.4
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5
  * Make xt_DELUDE and xt_TARPIT work under Linux >= 5.0
    when used in conjunction with bridges.
* Fri Sep  6 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.4
  * Support for Linux 5.3
- Drop remove_flags.patch
* Sun Aug  4 2019 Arjen de Korte <suse+build@de-korte.org>
- Remove unused variable 'flags' from 'struct shash_desc'
  * Support for Linux 5.2 (add remove_flags.patch)
* Thu Mar  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.3
  * Support for Linux 5.0 [boo#1127790]
* Fri Sep  7 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.2
  * xt_geoip_build: change the way the source directory is scanned
* Wed Sep  5 2018 Jan Engelhardt <jengelh@inai.de>
- Add perl dependencies
* Tue Aug 14 2018 jengelh@inai.de
- Update to new upstream release 3.1 [boo#1104749]
  * Support for Linux 4.18
* Tue Jun 19 2018 msuchanek@suse.com
- Use %%{?linux_make_arch} when building kernel modules (boo#1098050).
* Mon Feb 12 2018 jengelh@inai.de
- Update to new upstream release 3.0
  * Support for Linux 4.16
  * Dropped support for Linux kernels older than 4.15
- Remove init_timer.patch
* Mon Feb  5 2018 suse+build@de-korte.org
- Backport from upstream
  * Support for Linux 4.15 (add init_timer.patch)
* Wed Nov 22 2017 jengelh@inai.de
- Update to new upstream release 2.14
  * Support for Linux 4.14 [boo#1068098]
  * DNETMAP buffer overflow fix
* Thu Aug 24 2017 jengelh@inai.de
- Bundle LICENSE file in BRPM
* Thu Jun 29 2017 jengelh@inai.de
- Update to new upstream release 2.13
  * Support for Linux 4.12
  * xt_condition: namespace support
  * xt_geoip: check for allocation overflow
  * xt_DNETMAP: fix a buffer overflow
* Wed Jan 11 2017 jengelh@inai.de
- Update to new upstream release 2.12
  * Support for Linux 4.10
* Fri May 20 2016 jengelh@inai.de
- Update to new upstream release 2.11
  * Support for Linux 4.5, 4.6
* Fri Nov 20 2015 jengelh@inai.de
- Update to new upstream release 2.10
  * Support for Linux 4.4
* Mon Oct 12 2015 jengelh@inai.de
- Update to new upstream release 2.9
  * Support for Linux 4.3
* Wed Aug 19 2015 jengelh@inai.de
- Update to new upstream release 2.8
  * Support for Linux 4.2
  * Enable xt_ECHO
* Mon Jul  6 2015 jengelh@inai.de
- Update to new upstream release 2.7
  * Support for Linux up to 4.1
* Mon Sep 29 2014 jengelh@inai.de
- Update to new upstream release 2.6
  * Fixes to the UDP SPA mode
  * Support for Linux 3.17
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 2.5
  * Support for Linux 3.14, 3.15
  * xt_quota2: support distinct network namespaces
* Thu Jan  9 2014 jengelh@inai.de
- Update to new upstream release 2.4
  * Support for Linux 3.13
  * Remove the unmaintained RAWSNAT/RAWDNAT modules
* Tue Jun 18 2013 jengelh@inai.de
- Update to new upstream release 3.10
  * support for Linux 3.10 and CONFIG_UIDGID_STRICT_TYPE_CHECKS
  * xt_geoip: do not throw a warning when country database is size 0
  * xt_quota2: print "!" at the correct position during iptables-save
* Sun Mar 31 2013 jengelh@inai.de
- Update to new upstream release 2.2
  * support for Linux 3.9
  * avoid iptaccount being optimized away (bnc#807155)
* Thu Feb 28 2013 coolo@suse.com
- update license to new format
* Fri Jan  4 2013 jengelh@inai.de
- Don't need linux-glibc 3.7, since we copy headers anyway
* Thu Dec 27 2012 jengelh@inai.de
- Update to new upstream release 2.1
  * support for Linux 3.8
- Remove 0001-xt_DNETMAP-fix-compile-error-with-Linux-3.7.patch
* Fri Dec 21 2012 jengelh@inai.de
- Always ship all source tarballs to make osc validator happy
- Enable version 2.0 for openSUSE:Factory which now has kernel 3.7
- Add 0001-xt_DNETMAP-fix-compile-error-with-Linux-3.7.patch
* Mon Dec  3 2012 sbrabec@suse.cz
- Verify GPG signature.
* Mon Nov 12 2012 jengelh@inai.de
- Update to new upstream release 2.0
  (enabled for Kernel:HEAD only at this time)
  * Support for Linux 3.7
* Mon Oct 15 2012 jengelh@inai.de
- Update to new upstream release 1.47.1
  * Support for IPv6 in xt_psd
* Thu Aug 23 2012 jengelh@inai.de
- Update to new upstream release 1.46
  * length2, SYSRQ, RAWNAT: preinitialize values for ipv6_find_hdr
  * TARPIT: fix memory leak when tarpit_generic() fails
  * Support for Linux 3.6
* Sun Jul 15 2012 jengelh@inai.de
- Update to new upstream release 1.45
  * SYSRQ: fix double target initialization at module load
  * TARPIT: IPv6 support
* Sat Jun 30 2012 jengelh@inai.de
- Update to new upstream release 1.43
  * xt_psd: avoid crash due to curr->next corruption
  * xt_psd: reject invalid match options
  * DNETMAP: new type: static binding
  * DNETMAP: new persistent flag option for prefix
  * DNETMAP: add write support to procfs interface
* Thu Apr  5 2012 jengelh@medozas.de
- update to new upstream release 1.42
  * Linux 3.3/3.4 support
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Jan  4 2012 jengelh@medozas.de
- update to new upstream release 1.41
  * support for Linux 3.2
* Fri Dec 30 2011 jengelh@medozas.de
- We have now a few of kernel versions that ipset can be compiled
  against, so ipset has been separated out into a new RPM package,
  and ipset-genl from xtables-addons is hereby subsequently
  disabled.
* Wed Nov 30 2011 jengelh@medozas.de
- update to new upstream release 1.40
  * xt_ECHO: fix kernel warning about RTAX_HOPLIMIT being used
  * xt_ipv4options: fix an infinite loop
  * Provides ipset 6.10: ICMP/ICMPv6 type/code parser bug fixed;
  fix lookup of tcp port names
* Wed Sep 21 2011 jengelh@medozas.de
- update to new upstream release 1.39
  * update to ipset 6.9.1
  * resolve compilation errors due to missing libxtables_CFLAGS
* Sat Aug 20 2011 jengelh@medozas.de
- update to new upstream release 1.38
  * Restore UDP functionality for xt_psd
  * UDPLITE support for xt_SYSRQ, xt_ipp2p, xt_pknock, xt_psd
  * Provides ipset 6.8
* Sat Jun 25 2011 jengelh@medozas.de
- update to new upstream release 1.37
  * xt_SYSRQ: make IPv6 trigger work again
  * xt_SYSRQ: improve security: include host address in digest
  * xt_TARPIT: fix a kernel oops in --reset mode
* Fri Jun  3 2011 jengelh@medozas.de
- update to new upstream release 1.36
  * update to ipset 6.7
  * xt_TARPIT has gained the "honeypot" and "reset" modes
* Mon Apr 11 2011 jengelh@medozas.de
- Update to new upstream release 1.35
  * update to ipset 6.3
  * ipset-genl: handle EAGAIN return value emitted from autoloader
  * ipset-genl: resolve nfgenmsg remains and fix spurious protocol abort
* Thu Apr  7 2011 jengelh@medozas.de
- Update to new upstream release 1.34
  * xt_pknock: avoid crash when hash TFM could not be allocated
  * xt_pknock: avoid inversion of rule lookup that led to warnings
  * xt_DNETMAP: add missing module alias
  * xt_DNETMAP: support for kernels below 2.6.34
- Add kmp preamble file
* Wed Feb  2 2011 jengelh@medozas.de
- Update to new upstream release 1.33
  * IPv6 GeoIP support
  * New DNETMAP extension
  * Update to ipset 5.4-genl
* Fri Nov  5 2010 jengelh@medozas.de
- Update to new upstream release 1.31
  * LOGMARK: print remaining lifetime of ct entries
  * xt_iface: allow matching against incoming/outgoing interface
  * libxt_gradm: match packets based on status of grsecurity RBAC
* Sat Oct  9 2010 jengelh@medozas.de
- Do not build xt_TEE, xt_CHECKSUM; they are provided in newer
  iptables and kernel versions already
* Sun Oct  3 2010 jengelh@medozas.de
- new upstream release 1.30
  * support for Linux 2.6.36
  * update to ipset 4.4
  - ipport{,ip,net}hash did not work with mixed "src" and "dst"
    destination parameters
  * do ship ip_set_ipport{ip,net}hash
* Sat Jul 24 2010 jengelh@medozas.de
- new upstream release 1.28
  * RAWNAT: IPv6 variants erroneously rejected masks /33-/128
  * new target xt_CHECKSUM
  * xt_length2: add support for IPv6 jumbograms
  * xt_geoip: fix possible out-of-bounds access
  * import xt_geoip database scripts
* Tue Jun 29 2010 lnussel@suse.de
- don't require kernel module package (bnc#618244)
* Mon May 17 2010 jengelh@medozas.de
- new upstream release 1.27
  * support for upcoming Linux 2.6.35
* Sat May  1 2010 jengelh@medozas.de
- new upstream release 1.26
  * fix compile error with kernel 2.6.34
* Mon Apr 26 2010 jengelh@medozas.de
- new upstream release 1.25
  * incorporated changes from upstream review into xt_TEE:
    (rechecksumming in PREROUTING, decrease TTL on cloned packet, set
    dont-fragment on cloned packets, free skb when route lookup
    failed, do not limit use to mangle table, do not retain iif and
    mark on cloned packet, new loop detection logic, use less
    expensive pskb_copy)
* Wed Mar 17 2010 jengelh@medozas.de
- new upstream release 1.24
  * ipp2p: updated bittorent command recognition
* Thu Feb 25 2010 jengelh@medozas.de
- new upstream release 1.23
  * ipset updated to 4.2
  * removal of obsoleted configure options;
    compile fixes for IPV6=n and 2.6.32's skb_dst
  * support for Linux 2.6.33 and the projected 2.6.34 net tree
* Thu Feb 11 2010 ro@suse.de
- add KMP to specfile (to give description to kmp subpacks)
* Sat Jan 23 2010 jengelh@medozas.de
- new upstream release 1.22
  * ipset: enable build of ip_set_setlist.ko
  * quota2: add the --no-change mode
- remove merged patch geoip-dir.diff (use
  /usr/share/xt_geoip instead of /var/geoip)
* Thu Dec 31 2009 jengelh@medozas.de
- initial OBS package
* Wed Dec  9 2009 jengelh@medozas.de
- new upstream release: 1.21
  * fix clashing setsockopt numbers between xt_ACCOUNT and arptables
* Thu Nov 19 2009 jengelh@medozas.de
- new upstream release: 1.20
* Mon Oct 12 2009 jengelh@medozas.de
- new upstream release: 1.19
